@@ -21,14 +21,13 @@
 
 #include "knewstuffcore_export.h"
 
-#include <memory>
-
 class QTimer;
 class KJob;
 class EnginePrivate;
 
 namespace Attica
 {
+class ProviderManager;
 class Provider;
 }
 
@@ -80,18 +79,6 @@ class KNEWSTUFFCORE_EXPORT Engine : public QObject
      */
     Q_PROPERTY(QString useLabel READ useLabel NOTIFY useLabelChanged)
 
-    /**
-     * Whether or not the configuration says that the providers are expected to support uploading.
-     * As it stands, this is used to determine whether or not to show the Upload... action where
-     * that is displayed (primarily NewStuff.Page).
-     * @since 5.85
-     */
-    Q_PROPERTY(bool uploadEnabled READ uploadEnabled NOTIFY uploadEnabledChanged)
-
-    /**
-     * @since 5.85
-     */
-    Q_PROPERTY(QStringList providerIDs READ providerIDs NOTIFY providersChanged)
 public:
     /**
      * Constructor.
@@ -102,7 +89,7 @@ public:
      * Destructor. Frees up all the memory again which might be taken
      * by cached entries and providers.
      */
-    ~Engine() override;
+    ~Engine();
 
     enum class BusyOperation {
         Initializing,
@@ -448,8 +435,6 @@ public:
      */
     QList<Provider::CategoryMetadata> categoriesMetadata();
 
-    QList<Provider::SearchPreset> searchPresets();
-
 #if KNEWSTUFFCORE_ENABLE_DEPRECATED_SINCE(5, 77)
     /**
      * The adoption command can be used to allow a user to make use of an entry's
@@ -508,15 +493,6 @@ public:
      */
     void setPageSize(int pageSize);
 
-    /**
-     * @returns the page size we previously set
-     * @see requestData(int,int)
-     *
-     * @since 5.95
-     */
-    int pageSize() const;
-
-#if KNEWSTUFFCORE_ENABLE_DEPRECATED_SINCE(5, 83)
     /**
      * Get a list of all the locations which will be used when searching for knsrc
      * files, in the order in which the search will occur.
@@ -524,13 +500,8 @@ public:
      * @param includeFallbackLocations Whether or not the deprecated search locations are included
      * @return The search list for knsrc files
      * @since 5.57
-     * @deprecated Since 5.83, use Engine::availableConfigFiles instead
      */
-    KNEWSTUFFCORE_DEPRECATED_VERSION(5, 83, "Use Engine::availableConfigFiles instead")
     static QStringList configSearchLocations(bool includeFallbackLocations = false);
-#endif
-
-#if KNEWSTUFFCORE_ENABLE_DEPRECATED_SINCE(5, 83)
     /**
      * Sets whether or not the config file location discovery fallback should be active.
      * If enabled (default), if the config file is not found in the knsrcfiles location,
@@ -539,18 +510,8 @@ public:
      *
      * @param enableFallback Whether or not the fallback discovery should be enabled
      * @since 5.57
-     * @deprecated Since 5.83, the engine includes the fallback paths by default
      */
-    KNEWSTUFFCORE_DEPRECATED_VERSION(5, 83, "The engine includes the fallback paths by default")
     void setConfigLocationFallback(bool enableFallback);
-#endif
-
-    /**
-     * List of all available config files. This list will contain no duplicated filenames.
-     * The returned file paths are absolute.
-     * @since 5.83
-     */
-    static QStringList availableConfigFiles();
 
     /**
      * The Provider instance with the passed ID
@@ -568,20 +529,6 @@ public:
      */
     QSharedPointer<Provider> defaultProvider() const;
 
-    /**
-     * The IDs of all providers known by this engine. Use this in combination with
-     * provider(const QString&) to iterate over all providers.
-     * @return The string IDs of all known providers
-     * @since 5.85
-     */
-    QStringList providerIDs() const;
-
-    /**
-     * Fired whenever the list of providers changes
-     * @since 5.85
-     */
-    Q_SIGNAL void providersChanged();
-
     /**
      * This function will return an instance of a model which contains comments for
      * the entry passed to it. The model may be empty (if there are no comments for
@@ -655,25 +602,6 @@ public:
      */
     Q_INVOKABLE void revalidateCacheEntries();
 
-    /**
-     * Whether or not the configuration says that the providers are expected to support uploading.
-     * @return True if the providers are expected to support uploading
-     * @since 5.85
-     */
-    bool uploadEnabled() const;
-
-    /**
-     * Fired when the uploadEnabled property changes
-     * @since 5.85
-     */
-    Q_SIGNAL void uploadEnabledChanged();
-
-    /**
-     * @returns the list of attica (OCS) providers this engine is connected to
-     * @since 5.92
-     */
-    QVector<Attica::Provider *> atticaProviders() const;
-
 Q_SIGNALS:
     /**
      * Indicates a message to be added to the ui's log, or sent to a messagebox
@@ -732,43 +660,32 @@ Q_SIGNALS:
 
     void signalCategoriesMetadataLoded(const QList<Provider::CategoryMetadata> &categories);
 
-    /**
-     * Fires when the engine has loaded search presets. These represent interesting
-     * searches for the user, such as recommendations.
-     * @since 5.83
-     */
-    void signalSearchPresetsLoaded(const QList<Provider::SearchPreset> &presets);
-    /**
-     * This is fired for any event related directly to a single EntryInternal instance
-     * @see EntryInternal::EntryEvent for details on which specific event is being notified
-     * @since 5.77
-     */
     void signalEntryEvent(const EntryInternal &entry, EntryInternal::EntryEvent event);
 
 private Q_SLOTS:
     // the .knsrc file was loaded
-    KNEWSTUFFCORE_NO_EXPORT void slotProviderFileLoaded(const QDomDocument &doc);
+    void slotProviderFileLoaded(const QDomDocument &doc);
     // instead of getting providers from knsrc, use what was configured in ocs systemsettings
-    KNEWSTUFFCORE_NO_EXPORT void atticaProviderLoaded(const Attica::Provider &provider);
+    void atticaProviderLoaded(const Attica::Provider &provider);
 
     // loading the .knsrc file failed
-    KNEWSTUFFCORE_NO_EXPORT void slotProvidersFailed();
+    void slotProvidersFailed();
 
     // called when a provider is ready to work
-    KNEWSTUFFCORE_NO_EXPORT void providerInitialized(KNSCore::Provider *);
+    void providerInitialized(KNSCore::Provider *);
 
-    KNEWSTUFFCORE_NO_EXPORT void slotEntriesLoaded(const KNSCore::Provider::SearchRequest &, KNSCore::EntryInternal::List);
-    KNEWSTUFFCORE_NO_EXPORT void slotEntryDetailsLoaded(const KNSCore::EntryInternal &entry);
-    KNEWSTUFFCORE_NO_EXPORT void slotPreviewLoaded(const KNSCore::EntryInternal &entry, KNSCore::EntryInternal::PreviewType type);
+    void slotEntriesLoaded(const KNSCore::Provider::SearchRequest &, KNSCore::EntryInternal::List);
+    void slotEntryDetailsLoaded(const KNSCore::EntryInternal &entry);
+    void slotPreviewLoaded(const KNSCore::EntryInternal &entry, KNSCore::EntryInternal::PreviewType type);
 
-    KNEWSTUFFCORE_NO_EXPORT void slotSearchTimerExpired();
+    void slotSearchTimerExpired();
 
-    KNEWSTUFFCORE_NO_EXPORT void slotEntryChanged(const KNSCore::EntryInternal &entry);
-    KNEWSTUFFCORE_NO_EXPORT void slotInstallationFinished();
-    KNEWSTUFFCORE_NO_EXPORT void slotInstallationFailed(const QString &message);
-    KNEWSTUFFCORE_NO_EXPORT void downloadLinkLoaded(const KNSCore::EntryInternal &entry);
+    void slotEntryChanged(const KNSCore::EntryInternal &entry);
+    void slotInstallationFinished();
+    void slotInstallationFailed(const QString &message);
+    void downloadLinkLoaded(const KNSCore::EntryInternal &entry);
 
-    KNEWSTUFFCORE_NO_EXPORT void providerJobStarted(KJob *);
+    void providerJobStarted(KJob *);
 
 private:
     /**
@@ -793,7 +710,6 @@ private:
     QSharedPointer<Cache> m_cache;
     QTimer *m_searchTimer;
     // The url of the file containing information about content providers
-    /// TODO KF6 This really wants to be turned into a QUrl (which will have implications for our public API, so not doing it just now)
     QString m_providerFileUrl;
     // Categories from knsrc file
     QStringList m_categories;
@@ -805,7 +721,7 @@ private:
     // the current request from providers
     Provider::SearchRequest m_currentRequest;
 
-    const std::unique_ptr<EnginePrivate> d;
+    EnginePrivate *const d;
 
     // the page that is currently displayed, so it is not requested repeatedly
     int m_currentPage;
